@@ -22,26 +22,36 @@
 
 int main (int argc, char* argv[])
 {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     bool success = Gst::init_check();
 
-    if (!success)
+    if(!success)
     {
       std::cout << "Error initializing gstreamermm." << std::endl;
       return -1;
     }
 
   }
-  catch (const Glib::Error& error)
+  catch(const Glib::Error& error)
   {
     std::cout << "Error initializing gstreamermm." << std::endl;
     return -1;
   }
-
+#else
+  std::auto_ptr<Glib::Error> error;
+  bool success = Gst::init_check(error);
+  if(!success)
+  {
+    std::cout << "Error initializing gstreamermm." << std::endl;
+    if(error.get())
+      std::cout << "Error: " << error->what() << std::endl;
+  }
+#endif
   Glib::RefPtr<Gst::Element> element = Gst::ElementFactory::create_element("ximagesink", "videosink");
 
-  if (element)
+  if(element)
     std::cout << "Successfully created gst element '" <<
       element->get_name() << "'." << std::endl;
 
